Python: module excerpts.cui

excerpts.cui | index /home/qwer/git/cyclops/fvafrcu/excerpts/excerpts/cui.py

`## @file
# user interface functions`

Modules
`` |  |
excerpts.cmain | excerpts.cos |  |

Functions
`` |  | excerpt(file_name, comment_character='#', magic_character='%', prefix='', postfix='', run_pandoc=True, compile_latex=False, pandoc_formats='tex') `## Extract, Convert and Save Markdown Style Comments From a File # # This is merely a wrapper to get_toc(), modify_path() and pandoc(). # @param file_name The file from which the lines are to be extracted. # @param pandoc_formats The pandoc output formats to be used. # @param run_pandoc Run pandoc on the markdown file created? # @param compile_latex Compile the LaTeX file? # @param postfix Set the output file postfix. # @param prefix Set the output file prefix. # @param comment_character The comment character of the files language ("#" for # example. # @param magic_character The magic character marking lines as markdown # comments. # @return True if output generation was successful.`